# erkc63

Клиент [личного кабинета ЕРКЦ](https://lk.erkc63.ru/).

Писался как отдельная [PyPI](https://pypi.org/project/erkc63/) библиотека для интеграции данных в [Home Assistant](https://www.home-assistant.io/).
